@@ -557,3 +557,52 @@ gpe_launch_program (Display *dpy, char *exec, char *name)
   return gpe_launch_program_with_callback (dpy, exec, name, FALSE, NULL, NULL);
 }
 
+void
+gpe_launch_activate_window (Display *dpy, Window win)
+{
+  static Atom atom_net_active = None;
+  XEvent ev;
+
+  if (atom_net_active == None)
+    atom_net_active = XInternAtom (dpy, "_NET_ACTIVE_WINDOW", False);
+
+  memset (&ev, 0, sizeof ev);
+  ev.xclient.type = ClientMessage;
+  ev.xclient.window = win;
+  ev.xclient.message_type = atom_net_active;
+  ev.xclient.format = 32;
+
+  XSendEvent (dpy, RootWindow (dpy, DefaultScreen (dpy)), False, SubstructureRedirectMask, &ev);
+}
+
+#define MY_LD_PRELOAD "/usr/lib/librewrite.so.0"
+
+void
+gpe_launch_set_root (const gchar *root)
+{
+  static gboolean initialised;
+  static gchar *old_ld_preload, *new_ld_preload;
+
+  if (!initialised)
+    {
+      old_ld_preload = getenv ("LD_PRELOAD");
+      if (old_ld_preload)
+	new_ld_preload = g_strdup_printf ("%s:%s", old_ld_preload, MY_LD_PRELOAD);
+      else
+	new_ld_preload = MY_LD_PRELOAD;
+    }
+
+  if (root)
+    {
+      setenv ("REWRITE_ROOT", root, 1);
+      setenv ("LD_PRELOAD", new_ld_preload, 1);
+    }
+  else
+    {
+      unsetenv ("REWRITE_ROOT");
+      if (old_ld_preload)
+	setenv ("LD_PRELOAD", old_ld_preload, 1);
+      else
+	unsetenv ("LD_PRELOAD");
+    }
+}
